@@ -7,22 +7,6 @@ import { selectFacilityIds } from '@tamanu/utils/selectFacilityIds';
 import { GLOBAL_EXCLUDE_TABLES, NON_LOGGED_TABLES, NON_SYNCING_TABLES } from './constants';
 import { SYNC_TICK_FLAGS } from '../../sync/constants';
 
-const tableNameMatch = (schema: string, table: string, matches: string[]) => {
-  const matchTableSchemas = matches
-    .map(match => match.split('.'))
-    .map(([excludeSchema, excludeTable]) => ({ schema: excludeSchema, table: excludeTable }));
-  const wholeSchemaMatches = matchTableSchemas
-    .filter(({ table: matchTable }) => matchTable === '*')
-    .map(({ schema: matchSchema }) => matchSchema);
-  if (wholeSchemaMatches.includes(schema)) {
-    return true;
-  }
-
-  return matchTableSchemas.some(
-    ({ schema: matchSchema, table: matchTable }) => schema === matchSchema && table === matchTable,
-  );
-};
-
 export const tablesWithoutColumn = (
   sequelize: Sequelize,
   column: string,
@@ -53,7 +37,7 @@ export const tablesWithoutColumn = (
           schema: (row as any).schema as string,
           table: (row as any).table as string,
         }))
-        .filter(({ schema, table }) => !tableNameMatch(schema, table, allExcludes)),
+        .filter(({ schema, table }) => !allExcludes.includes(`${schema}.${table}`)),
     );
 };
 export const tablesWithoutTrigger = (
@@ -88,7 +72,7 @@ export const tablesWithoutTrigger = (
           schema: (row as any).schema as string,
           table: (row as any).table as string,
         }))
-        .filter(({ schema, table }) => !tableNameMatch(schema, table, allExcludes)),
+        .filter(({ schema, table }) => !allExcludes.includes(`${schema}.${table}`)),
     );
 };
 
@@ -172,7 +156,20 @@ export async function runPostMigration(log: Logger, sequelize: Sequelize) {
       })
       .then(rows => (rows?.[0] as any)?.count > 0);
 
-  // add trigger: before insert or update, set updated_at (overriding any that is passed in)
+  // add trigger: before update, update updated_at when the data in the row changed
+  if (await functionExists('set_updated_at')) {
+    for (const { schema, table } of await tablesWithoutTrigger(sequelize, 'set_', '_updated_at')) {
+      log.info(`Adding updated_at trigger to ${schema}.${table}`);
+      await sequelize.query(`
+      CREATE TRIGGER set_${table}_updated_at
+      BEFORE INSERT OR UPDATE ON "${schema}"."${table}"
+      FOR EACH ROW
+      EXECUTE FUNCTION public.set_updated_at();
+    `);
+    }
+  }
+
+  // add trigger: before insert or update, set updated_at_sync_tick (overriding any that is passed in)
   if (await functionExists('set_updated_at_sync_tick')) {
     for (const { schema, table } of await tablesWithoutTrigger(
       sequelize,
